@@ -49,10 +49,18 @@ void BuiltinFunctionsLibImpl::initBuiltinKernel(Builtin func) {
         kernelName = "CopyBufferRectBytes2d";
         builtin = NEO::EBuiltInOps::copyBufferRect;
         break;
+    case Builtin::copyBufferRectBytes2dStateless:
+        kernelName = "CopyBufferRectBytes2dStateless";
+        builtin = NEO::EBuiltInOps::copyBufferRectStateless;
+        break;
     case Builtin::copyBufferRectBytes3d:
         kernelName = "CopyBufferRectBytes3d";
         builtin = NEO::EBuiltInOps::copyBufferRect;
         break;
+    case Builtin::copyBufferRectBytes3dStateless:
+        kernelName = "CopyBufferRectBytes3dStateless";
+        builtin = NEO::EBuiltInOps::copyBufferRectStateless;
+        break;
     case Builtin::copyBufferToBufferMiddle:
         kernelName = "CopyBufferToBufferMiddleRegion";
         builtin = NEO::EBuiltInOps::copyBufferToBuffer;
